<?php

namespace WPPayForm\Classes\Tools;

use WPPayForm\Classes\AccessControl;
use WPPayForm\Classes\ArrayHelper;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Managing Global Tools
 * @since 1.1.0
 */
class DemoForms
{

    public function registerEndpoints()
    {
        add_action('wp_ajax_wppayform_demo_forms', array($this, 'handeEndPoint'));
        add_action('wppayform/after_create_form', array($this, 'insertTemplateForm'), 10, 3);
    }

    public function handeEndPoint()
    {
        $route = sanitize_text_field($_REQUEST['route']);

        $validRoutes = array(
            'get_forms' => 'responseDemoForms'
        );

        if (isset($validRoutes[$route])) {
            AccessControl::checkAndPresponseError($route, 'demo_forms');
            do_action('wppayform/doing_ajax_forms_' . $route);
            return $this->{$validRoutes[$route]}();
        }
    }

    public function responseDemoForms()
    {
        $forms = $this->demoForms();
        $formattedForms = [];
        foreach ($forms as $formName => $form) {
            unset($form['data']);
            $formattedForms[$formName] =  $form;
        }
        wp_send_json_success(array(
            'demo_forms' => $formattedForms
        ), 200);
    }

    public function insertTemplateForm($formId, $data, $template)
    {
        $demoForms = $this->demoForms();
        if(!isset($demoForms[$template])) {
            return;
        }
        $demoForm = $demoForms[$template];

        $data = ArrayHelper::get($demoForm, 'data');
        if(!$data) {
            return;
        }

        $data = json_decode($data, true);

        $metas = ArrayHelper::get($data, 'form_meta');
        if(!is_array($metas)) {
            return;
        }
        foreach ($metas as $metaKey => $metaValue) {
            update_post_meta($formId, $metaKey, $metaValue);
        }
    }

    public function demoForms()
    {
        $demoForms = array(
            'contact_form'            => array(
                'label'         => 'Contact Form',
                'description'   => 'Create a simple contact form.',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/2.png',
                'data'          => '{"post_content":"","post_title":"Contact Form","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Customer Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Name","placeholder":"Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Customer Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"text","editor_title":"Single Line Text","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Subject","placeholder":"","required":"no"},"id":"text"},{"type":"textarea","editor_title":"Textarea Field","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"textarea","group":"general"}},"field_options":{"label":"Your Message","placeholder":"","required":"yes"},"id":"textarea"}],"wppayform_submit_button_settings":{"button_text":"Submit","processing_text":"Please Wait…","button_style":"wpf_default_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Form has been successfully submitted. We will contact with you as soon as possible</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"Contact form Submitted by {input.customer_name} #{submission.id}","email_body":"<p>The following data has been submitted by {input.customer_name}</p>\n<p>{submission.all_input_field_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/after_form_submission_complete","status":"active"}]}}',
                'is_pro'        => false
            ),
            'donation_form'           => array(
                'label'         => 'Donation Form',
                'description'   => 'Create a simple Donation form.',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/3.png',
                'data'          => '{"post_title":"Donation Form","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Customer Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Your Name","placeholder":"Your Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Customer Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Your Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"custom_payment_input","editor_title":"User Inputed Pay Amount","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"},"min_value":{"label":"Minimum Value","type":"text","group":"general"}},"field_options":{"label":"Your Donation Amount","placeholder":"Your Donation Amount","required":"yes","default_value":"25","min_value":"5"},"id":"custom_payment_input"},{"type":"stripe_card_element","editor_title":"Card Elements (Stripe)","editor_icon":"","group":"payment_method_element","method_handler":"stripe","postion_group":"payment_method","single_only":"true","editor_elements":{"label":{"label":"Field Label","type":"text"},"checkout_display_style":{"label":"Checkout display style","type":"checkout_display_options"},"verify_zip":{"label":"Verify Zip/Postal Code","type":"switch"}},"field_options":{"label":"Your Card info (Powered By Stripe)","verify_zip":"yes","checkout_display_style":{"style":"stripe_checkout","require_billing_info":"no","require_shipping_info":"no"}},"id":"stripe_card_element"}],"wppayform_submit_button_settings":{"button_text":"Donate {payment_total}","processing_text":"Please Wait…","button_style":"wpf_full_block_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Thank you for your donation.</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"New Donation Made By by {input.customer_name} #{submission.id}","email_body":"<p>Good news! New Donation made by {input.customer_name}</p>\n<p>{submission.all_input_field_html}</p>\n<p>Donation Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"active"}],"wppayform_show_title_description":""}}',
                'is_pro'        => false
            ),
            'event_registration'      => array(
                'label'         => 'Event Registration Form',
                'description'   => 'Create an Event Registration form and accept payment',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/4.png',
                'data'          => '{"post_title":"Event Registration Form","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Name","placeholder":"Your Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Choose Your Ticket","required":"yes","pricing_details":{"one_time_type":"choose_single","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Early Bird Ticket","value":"25"},{"label":"Regular Ticket","value":"35"}],"prices_display_type":"radio"}},"id":"payment_item"},{"type":"item_quantity","editor_title":"Item Quantity","group":"item_quantity","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Quantity","type":"text","group":"general"},"target_product":{"label":"Target Payment Item","type":"product_selector","group":"general","info":"Please select the product in where the quantity will be applied"},"min_value":{"label":"Minimum Quantity","type":"number","group":"general"},"max_value":{"label":"Maximum Quantity","type":"number","group":"general"}},"field_options":{"label":"Ticket Quantity","placeholder":"Provide Quantity","required":"yes","min_value":"1","target_product":"payment_item","default_value":"1"},"id":"item_quantity"},{"type":"stripe_card_element","editor_title":"Card Elements (Stripe)","editor_icon":"","group":"payment_method_element","method_handler":"stripe","postion_group":"payment_method","single_only":"true","editor_elements":{"label":{"label":"Field Label","type":"text"},"checkout_display_style":{"label":"Checkout display style","type":"checkout_display_options"},"verify_zip":{"label":"Verify Zip/Postal Code","type":"switch"}},"field_options":{"label":"Your Card info (Powered By Stripe)","verify_zip":"yes","checkout_display_style":{"style":"stripe_checkout","require_billing_info":"no","require_shipping_info":"no"}},"id":"stripe_card_element"}],"wppayform_submit_button_settings":{"button_text":"Register and Pay {payment_total}","processing_text":"Please Wait…","button_style":"wpf_full_block_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Thank you for your registration. Please contact with us if you have any query.</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"New Event Registration by {input.customer_name} #{submission.id}","email_body":"<p>Good news! New Registration made by {input.customer_name}</p>\n<p>{submission.all_input_field_html}</p>\n<p>Payment Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"active"},{"title":"Email Notification to Submitter","email_to":"{input.customer_email}","reply_to":"{wp:admin_email}","email_subject":"Event Registration Confirmation","email_body":"<p>Hello {input.customer_name},</p>\n<p>Thank you for completing the registration. Here is your payment receipt:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Your Registration ID: {submission.id}</p>\n<p>Thank You</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"disabled"}],"wppayform_show_title_description":""}}',
                'is_pro'        => false
            ),
            'multiple_item_sale'      => array(
                'label'         => 'Multiple items Sale',
                'description'   => 'Sale multiple products in a single form',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/5.png',
                'data'          => '{"post_title":"Multiple items Sale","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Customer Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Name","placeholder":"Your Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Customer Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Select the Product That you want to purchase","required":"yes","pricing_details":{"one_time_type":"choose_multiple","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Product 1","value":"25"},{"label":"Product 2","value":"35"},{"label":"Product 3","value":"50"}],"prices_display_type":"radio"}},"id":"payment_item"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Add On Products","required":"no","pricing_details":{"one_time_type":"choose_single","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Add-on Item 1","value":"10"},{"label":"Add-on Item 2","value":"15"}],"prices_display_type":"radio"}},"id":"payment_item_1"},{"type":"stripe_card_element","editor_title":"Card Elements (Stripe)","editor_icon":"","group":"payment_method_element","method_handler":"stripe","postion_group":"payment_method","single_only":"true","editor_elements":{"label":{"label":"Field Label","type":"text"},"checkout_display_style":{"label":"Checkout display style","type":"checkout_display_options"},"verify_zip":{"label":"Verify Zip/Postal Code","type":"switch"}},"field_options":{"label":"Your Card info (Powered By Stripe)","verify_zip":"yes","checkout_display_style":{"style":"stripe_checkout","require_billing_info":"no","require_shipping_info":"no"}},"id":"stripe_card_element"}],"wppayform_submit_button_settings":{"button_text":"Pay {payment_total}","processing_text":"Please Wait…","button_style":"wpf_full_block_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Thank you for your purchase. Your Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Your Order ID: {submission.id}</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"New Product Sale, Customer: {input.customer_name} #{submission.id}","email_body":"<p>Good news! New Sale</p>\n<p>Customer Info:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"active"},{"title":"Email Notification to Submitter","email_to":"{input.customer_email}","reply_to":"{wp:admin_email}","email_subject":"Thank You  for your Order","email_body":"<p>Hello {input.customer_name},</p>\n<p>Thank you for order. Here is your payment receipt:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Your Order ID: {submission.id}</p>\n<p>Thank You</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"disabled"}],"wppayform_show_title_description":""}}',
                'is_pro'        => false
            ),
            'paypal_payment_form'     => array(
                'label'         => 'PayPal Payment Form',
                'description'   => 'Accept Payment using paypal',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/6.png',
                'data'          => '{"post_title":"Paypal Payment Form","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Customer Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Name","placeholder":"Your Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Customer Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Select the Product That you want to purchase","required":"yes","pricing_details":{"one_time_type":"choose_multiple","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Product 1","value":"25"},{"label":"Product 2","value":"35"},{"label":"Product 3","value":"50"}],"prices_display_type":"radio"}},"id":"payment_item"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Add On Products","required":"no","pricing_details":{"one_time_type":"choose_single","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Add-on Item 1","value":"10"},{"label":"Add-on Item 2","value":"15"}],"prices_display_type":"radio"}},"id":"payment_item_1"},{"type":"paypal_gateway_element","editor_title":"Paypal payment gateway","editor_icon":"","group":"payment_method_element","method_handler":"paypal","postion_group":"payment_method","single_only":"true","editor_elements":{"label":{"label":"Field Label","type":"text"},"require_shipping_address":{"label":"Require Shipping Address","type":"switch"}},"field_options":{"label":"PayPal Payment Gateway","require_shipping_address":"yes"},"id":"paypal_gateway_element"}],"wppayform_submit_button_settings":{"button_text":"Pay with PayPal {payment_total}","processing_text":"Please Wait…","button_style":"wpf_default_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Thank you for your purchase. Your Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Your Order ID: {submission.id}</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"New Product Sale, Customer: {input.customer_name} #{submission.id}","email_body":"<p>Good news! New Sale</p>\n<p>Customer Info:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"active"},{"title":"Email Notification to Submitter","email_to":"{input.customer_email}","reply_to":"{wp:admin_email}","email_subject":"Thank You  for your Order","email_body":"<p>Hello {input.customer_name},</p>\n<p>Thank you for order. Here is your payment receipt:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Your Order ID: {submission.id}</p>\n<p>Thank You</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"disabled"}],"wppayform_show_title_description":""}}',
                'is_pro'        => true
            ),
            'multiple_payment_method' => array(
                'label'         => 'Multiple Payment Method Form',
                'description'   => 'Create form with PayPal and Stripe Payment Method',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/7.png',
                'data'          => '{"post_title":"Multiple Payment Method Form","form_meta":{"wppayform_paymentform_builder_settings":[{"type":"customer_name","editor_title":"Customer Name","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Name","placeholder":"Your Name","required":"yes"},"id":"customer_name"},{"type":"customer_email","editor_title":"Customer Email","group":"input","postion_group":"general","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"placeholder":{"label":"Placeholder","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"default_value":{"label":"Default Value","type":"text","group":"general"}},"field_options":{"label":"Email Address","placeholder":"Email Address","required":"yes","default_value":""},"id":"customer_email"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Select the Product That you want to purchase","required":"yes","pricing_details":{"one_time_type":"choose_multiple","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Product 1","value":"25"},{"label":"Product 2","value":"35"},{"label":"Product 3","value":"50"}],"prices_display_type":"radio"}},"id":"payment_item"},{"type":"payment_item","editor_title":"Payment Item","group":"payment","postion_group":"payment","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"required":{"label":"Required","type":"switch","group":"general"},"payment_options":{"type":"payment_options","group":"general","label":"Configure Payment Item","selection_type":"Payment Type","selection_type_options":{"one_time":"One Time Payment","one_time_custom":"One Time Custom Amount"},"one_time_field_options":{"single":"Single Item","choose_single":"Chose One From Multiple Item","choose_multiple":"Choose Multiple Items"}}},"is_system_field":"true","is_payment_field":"true","field_options":{"label":"Add On Products","required":"no","pricing_details":{"one_time_type":"choose_single","payment_amount":"10","show_onetime_labels":"yes","multiple_pricing":[{"label":"Add-on Item 1","value":"10"},{"label":"Add-on Item 2","value":"15"}],"prices_display_type":"radio"}},"id":"payment_item_1"},{"type":"choose_payment_method","editor_title":"Choose Payment Method Field","group":"payment_method_element","postion_group":"payment_method","single_only":"true","editor_elements":{"label":{"label":"Field Label","type":"text","group":"general"},"default_value":{"label":"Default Payment method","type":"text","group":"general"},"method_settings":{"label":"Payment Methods","type":"choose_payment_method","available_methods":{"stripe":{"label":"Credit/Debit Card (Stripe)","isActive":"true","editor_elements":{"label":{"label":"Payment Option Label","type":"text","default":"Pay with Card (Stripe)"},"checkout_display_style":{"label":"Checkout display style","type":"checkout_display_options","default":{"style":"stripe_checkout","require_billing_info":"no"}},"verify_zip":{"label":"Verify Zip/Postal Code","type":"switch"}}},"paypal":{"label":"Paypal","isActive":"true","editor_elements":{"label":{"label":"Payment Option Label","type":"text","default":"Pay with Paypal"},"require_shipping_address":{"label":"Require Shipping Address","type":"switch"}}},"offline":{"label":"Offline/Check Payment","isActive":"true","editor_elements":{"label":{"label":"Payment Method Title","type":"text","default":"Direct bank transfer"},"description":{"label":"Payment instruction (will be shown on the form)","type":"textarea","default":"Make your payment directly into our bank account. Please use your Order ID as the payment reference. The payment will be marked as paid once the amound is deposited"}}}},"group":"general"}},"field_options":{"label":"Select Payment Method","default_value":"","method_settings":{"prefered_method":"","payment_settings":{"stripe":{"enabled":"yes","label":"Pay with Card (Stripe)","checkout_display_style":{"style":"stripe_checkout","require_billing_info":"no"},"verify_zip":"yes"},"paypal":{"enabled":"yes","label":"Pay with Paypal","require_shipping_address":"no"},"offline":{"enabled":"no"}}}},"id":"choose_payment_method"}],"wppayform_submit_button_settings":{"button_text":"Pay Now {payment_total}","processing_text":"Please Wait…","button_style":"wpf_default_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Thank you for your purchase. Your Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Your Order ID: {submission.id}</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"New Product Sale, Customer: {input.customer_name} #{submission.id}","email_body":"<p>Good news! New Sale</p>\n<p>Customer Info:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Order Details:</p>\n<p>{submission.product_items_table_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"active"},{"title":"Email Notification to Submitter","email_to":"{input.customer_email}","reply_to":"{wp:admin_email}","email_subject":"Thank You  for your Order","email_body":"<p>Hello {input.customer_name},</p>\n<p>Thank you for order. Here is your payment receipt:</p>\n<p>{submission.all_input_field_html}</p>\n<p>Your Order ID: {submission.id}</p>\n<p>Thank You</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/form_payment_success","status":"disabled"}],"wppayform_show_title_description":""}}',
                'is_pro'        => true
            ),
            'blank_form'              => array(
                'label'         => 'Blank Form',
                'description'   => 'Create a blank form',
                'preview_image' => WPPAYFORM_URL . 'assets/images/forms/1.png',
                'data'          => '{"post_content":"","post_title":"Blank Form","form_meta":{"wppayform_submit_button_settings":{"button_text":"Submit","processing_text":"Please Wait…","button_style":"wpf_default_btn","css_class":""},"wppapyform_paymentform_confirmation_settings":{"confirmation_type":"custom","redirectTo":"samePage","messageToShow":"<p>Form has been successfully submitted</p>","samePageFormBehavior":"hide_form"},"wppayform_form_design_settings":{"labelPlacement":"top","asteriskPlacement":"none","submit_button_position":"left","extra_styles":{"wpf_default_form_styles":"yes","wpf_bold_labels":"no"}},"wpf_email_notifications":[{"title":"Admin Email Notification","email_to":"{wp:admin_email}","reply_to":"{input.customer_email}","email_subject":"Contact form Submitted by {input.customer_name} #{submission.id}","email_body":"<p>The following data has been submitted by {input.customer_name}</p>\n<p>{submission.all_input_field_html}</p>\n<p>Form Page URL: {wp:post_url}</p>","from_name":"","from_email":"","format":"html","email_template":"default","cc_to":"","bcc_to":"","conditions":"","sending_action":"wppayform/after_form_submission_complete","status":"disabled"}]}}',
                'is_pro'        => false
            ),
        );

        return apply_filters('wppayform/demo_forms', $demoForms);
    }
}